# yahoowizard
the package connects to yahoo's fantasy football api to monitor and to make recommendations for your draft.

Initial release. Version .000000000000000001. Very developmental.

Check out https://github.com/jwaggie14/yahoo-draft-wizard for more information.